FlImagePicker class abstract
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FlImagePicker
- Implementers
Constructors
- FlImagePicker({Key? key, FlImagePickerItemConfig itemConfig = const FlImagePickerItemConfig(), required ImagePickerController controller, bool disposeController = false, bool allowDelete = true})
-
const
Properties
- allowDelete → bool
-
是否显示删除按钮
final
- controller → ImagePickerController
-
资源控制器
final
- disposeController → bool
-
dispose controller.dispose();
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemConfig → FlImagePickerItemConfig
-
item 样式配置
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- actionsBuilder ↔ PickerActionBuilder
-
类型来源选择器
getter/setter pair
- checkPermission ↔ FlImagePickerCheckPermission?
-
权限申请
getter/setter pair
- imageBuilder ↔ FlImageBuilder
-
imageBuilder
getter/setter pair
- imagePicker ↔ ImagePicker
-
image picker
getter/setter pair
Static Methods
-
buildImageProvider(
dynamic value) → ImageProvider< Object> ? - value 转换为 ImageProvider
-
preview<
T> (BuildContext context, List< FlXFile> entities, {int initialIndex = 0}) → Future<T?> - 全屏预览
-
showPick(
PickerAction action, {FlImagePickerOptions options = const FlImagePickerOptions()}) → Future< List< FlXFile> > - show pick
-
showPickActions(
BuildContext context, List< PickerActionOptions> actions) → Future<PickerActionOptions?> - show pick actions
-
showPickWithActions(
BuildContext context, List< PickerActionOptions> actions, {FlImagePickerOptions options = const FlImagePickerOptions()}) → Future<List< FlXFile> > - show pick actions show pick